@@ -2,7 +2,7 @@ package Net::OAI::Base;
 
 use strict;
 use Carp qw ( croak );
-our $VERSION = 'v1.01.0';
+our $VERSION = 'v1.016.010';
 
 =head1 NAME
 
@@ -224,7 +224,8 @@ sub file {
     return( $self->{ file } );
 }
 
-
+# called by next() methods in ListRecords and ListIdentifiers
+# listAllIdentifiers and listAllRecords store a reference into $self->{harvester}
 sub handleResumptionToken {
     my ( $self, $method ) = @_;
 
@@ -233,8 +234,11 @@ sub handleResumptionToken {
 
     my $rToken = $self->resumptionToken();
     if ( $rToken ) { 
-	my $new = $harvester->$method( resumptionToken => $rToken->token(), 
-            metadataHandler => $self->{metadataHandler} );
+	my $new = $harvester->$method(
+            resumptionToken => $rToken->token(), 
+            metadataHandler => $self->{ metadataHandler },
+              recordHandler => $self->{ recordHandler },
+          );
 	$new->{ harvester } = $harvester;
 	%$self = %$new; 
 	return( $self->next() );
@@ -253,9 +257,7 @@ sub handleResumptionToken {
 
 =head1 AUTHORS
 
-=over 4 
-
-=item * Ed Summers <ehs@pobox.com>
+Ed Summers <ehs@pobox.com>
 
 =back
 
