@@ -1,8 +1,7 @@
 package Net::OAI::GetRecord;
 
 use strict;
-use base qw( XML::SAX::Base );
-use base qw( Net::OAI::Base );
+use base qw( XML::SAX::Base Net::OAI::Base );
 use Net::OAI::Record::Header;
 
 =head1 NAME
@@ -32,11 +31,11 @@ sub new {
         delete $opts{ recordHandler };
 	$package = $opts{ metadataHandler } = 'Net::OAI::Record::OAI_DC';
     }
-    Net::OAI::Harvester::_verifyMetadataHandler( $package );
+    Net::OAI::Harvester::_verifyHandler( $package );
 
     my $self = bless \%opts, ref( $class ) || $class;
     $self->{ header } = undef;
-#   $self->{ setSpecs } = [];
+    $self->{ _prefixmap } = {};
     return( $self );
 }
 
@@ -53,6 +52,8 @@ sub record {
 
 =head2 header()
 
+Shortcut to the C<header()> method of the L<Net::OAI::Record> fetched.
+
 =cut
 
 sub header {
@@ -62,28 +63,46 @@ sub header {
 
 =head2 metadata()
 
+Shortcut to the C<metadata()> method of the L<Net::OAI::Record> fetched.
+May be undefined in case of deleted records or if no metadataHandler
+was provided.
+
 =cut
 
 sub metadata {
     my $self = shift;
     return undef unless $self->{ record };
-    return $self->{ recordHandler } ? undef : $self->{ record }->metadata();
+    return $self->{ metadataHandler } ? $self->{ record }->metadata() : undef;
 }
 
 
-=head2 alldata()
+=head2 recorddata()
 
 =cut
 
-sub alldata {
+sub recorddata {
     my $self = shift;
     return undef unless $self->{ record };
-    return $self->{ recordHandler } ? $self->{ record }->alldata() : undef;
+    return $self->{ recordHandler } ? $self->{ record }->recorddata() : undef;
 }
 
 
 ## SAX Handlers doing about the same as those of ListRecords.pm
 
+sub start_prefix_mapping {
+  my ($self, $mapping) = @_;
+  if ( $self->get_handler() ) {
+      return $self->SUPER::start_prefix_mapping( $mapping )};
+  $self->{ _prefixmap }->{$mapping->{ Prefix }} = $mapping;
+}
+
+sub end_prefix_mapping {
+  my ($self, $mapping) = @_;
+  if ( $self->get_handler() ) {
+      return $self->SUPER::end_prefix_mapping( $mapping )};
+  delete $self->{ _prefixmap }->{$mapping->{ Prefix }};
+}
+
 sub start_element {
     my ( $self, $element ) = @_;
     return $self->SUPER::start_element($element) unless $element->{NamespaceURI} eq Net::OAI::Harvester::XMLNS_OAI;
@@ -103,6 +122,8 @@ sub start_element {
 			Handler => (ref($self->{ metadataHandler }) ? $self->{ metadataHandler } : $self->{ metadataHandler }->new()),
 		     );
 	$self->set_handler( $header );
+        foreach my $mapping ( values %{$self->{_prefixmap}} ) {
+            $self->SUPER::start_prefix_mapping($mapping)};
     }
     return $self->SUPER::start_element( $element );
 }
@@ -121,7 +142,7 @@ sub end_element {
 	$header->set_handler( undef ); ## remove reference to $metadata
         my $record;
         if ( $self->{ recordHandler } ) {
-	    $record = Net::OAI::Record->new(header => $header, alldata => $data)
+	    $record = Net::OAI::Record->new(header => $header, recorddata => $data)
         } else {
 	    $record = Net::OAI::Record->new(header => $header, metadata => $data)
 	};
