@@ -22,7 +22,7 @@ use Net::OAI::ListSets;
 use Net::OAI::Record::Header;
 use Net::OAI::Record::OAI_DC;
 
-our $VERSION = '1.16_09';
+our $VERSION = '1.16_10';
 our $DEBUG = 0;
 
 =head1 NAME
@@ -231,15 +231,11 @@ sub identify {
     my $identity = Net::OAI::Identify->new( $self->_get( $uri ) );
     return $identity if $identity->{ error };
 
-#    my $token = Net::OAI::ResumptionToken->new( Handler => $identity );
-#    my $error = Net::OAI::Error->new( Handler => $token );
     my $error = Net::OAI::Error->new( Handler => $identity );
     my $parser = _parser( $error ); 
     debug( "parsing Identify response " .  $identity->file() );
     eval { $parser->parse_uri( $identity->file() ) };
-    if ( $@ ) {_xmlError( $error ); } 
-#    $token->set_handler( undef );
-#    $identity->{ token } = $token->token() ? $token : undef;
+    if ( $@ ) { _xmlError( $error ); } 
     $error->set_handler( undef );
     $identity->{ error } = $error;
     return( $identity );
@@ -277,14 +273,11 @@ sub listMetadataFormats {
     my $list = Net::OAI::ListMetadataFormats->new( $self->_get( $uri ) );
     return $list if $list->{ error };
 
-    my $token = Net::OAI::ResumptionToken->new( Handler => $list );
-    my $error = Net::OAI::Error->new( Handler => $token );
+    my $error = Net::OAI::Error->new( Handler => $list );
     my $parser = _parser( $error );
     debug( "parsing ListMetadataFormats response: ".$list->file() );
-    eval{ $parser->parse_uri( $list->file() ) };
+    eval { $parser->parse_uri( $list->file() ) };
     if ( $@ ) { _xmlError( $error ); } 
-    $token->set_handler( undef );
-    $list->{ token } = $token->token() ? $token : undef;
     $error->set_handler( undef );
     $list->{ error } = $error;
     return( $list );
@@ -331,32 +324,19 @@ or an already instantiated object of that class.
 	identifier		=> 'abc123',
 	recordHandler		=> 'MyCompleteHandler'
     );
-    my $complete_record = $result->alldata(); # undef if error or harvested with metadataHandler
+    my $complete_record = $result->recorddata(); # undef if error or harvested with metadataHandler
     
 =cut 
 
 sub getRecord {
     my ( $self, %opts ) = @_;
 
-    croak( "you must pass the identifier parameter to getRecord()" )
-	if ( ! exists( $opts{ 'identifier' } ) );
-    croak( "you must pass the metadataPrefix parameter to getRecord()" )
-	if ( ! exists( $opts{ 'metadataPrefix' } ) );
-    croak( "recordHandler and metadataHandler are mutually exclusive parameters for getRecord()" )
-        if exists $opts{ recordHandler } and exists $opts{ metadataHandler };
-
-#    my ($recordHandler, $metadataHandler);
-#    if ( exists( $opts{ recordHandler } ) ) {  
-#	my $package = $opts{ recordHandler };
-#	_verifyMetadataHandler( $package );
-#	$recordHandler = ref($package) ? $package : $package->new();
-#    } elsif ( exists( $opts{ metadataHandler } ) ) {  
-#	my $package = $opts{ metadataHandler };
-#	_verifyMetadataHandler( $package );
-#	$metadataHandler = ref($package) ? $package : $package->new();
-#    } else {
-#	$metadataHandler = Net::OAI::Record::OAI_DC->new();
-#    }
+    croak( "getRecord(): the 'identifier' parameter is required" )
+	unless defined $opts{ 'identifier' };
+    croak( "getRecord(): the 'metadataPrefix' parameter is required" )
+	unless exists $opts{ 'metadataPrefix' };
+    croak( "getRecord(): recordHandler and metadataHandler are mutually exclusive" )
+        if $opts{ recordHandler } and $opts{ metadataHandler };
 
     my $uri = $self->{ baseURL }->clone();
 
@@ -373,7 +353,7 @@ sub getRecord {
     my $error = Net::OAI::Error->new( Handler => $record );
     my $parser = _parser( $error ); 
     debug( "parsing GetRecord response " . $record->file() );
-    $parser->parse_uri( $record->file() );
+    eval { $parser->parse_uri( $record->file() ) };
     if ( $@ ) { _xmlError( $error ); } 
 
     $error->set_handler( undef );
@@ -463,11 +443,11 @@ used by your filter(s).
 sub listRecords {
     my ( $self, %opts ) = @_;
 
-    croak( "you must pass the metadataPrefix parameter to listRecords()" )
-	if ( ! exists( $opts{ 'metadataPrefix' } )
-	    and ! exists( $opts{ 'resumptionToken' } ) );
-    croak( "recordHandler and metadataHandler are mutually exclusive parameters for listRecords()" )
-        if exists $opts{ recordHandler } and exists $opts{ metadataHandler };
+    croak( "listRecords(): the 'metadataPrefix' parameter is required" )
+	unless ( exists $opts{ 'metadataPrefix' } 
+              or defined $opts{ 'resumptionToken' } );
+    croak( "listRecords(): recordHandler and metadataHandler are mutually exclusive" )
+        if $opts{ recordHandler } and $opts{ metadataHandler };
 
     my $uri = $self->{ baseURL }->clone();
 
@@ -490,8 +470,10 @@ sub listRecords {
 
     $token->set_handler( undef );
     $list->{ token } = $token->token() ? $token : undef;
+
     $error->set_handler( undef );
     $list->{ error } = $error;
+
     return( $list );
 }
 
@@ -515,7 +497,7 @@ sub listAllRecords {
 listIdentifiers() takes the same parameters that listRecords() takes, but it 
 returns only the record headers, allowing you to quickly retrieve all the 
 record identifiers for a particular repository. The object returned is a 
-Net::OAI::ListIdentifiers object.
+L<Net::OAI::ListIdentifiers> object.
 
     my $headers = $harvester->listIdentifiers( 
 	metadataPrefix	=> 'oai_dc'
@@ -535,9 +517,9 @@ in listRecords().
 
 sub listIdentifiers {
     my ( $self, %opts ) = @_;
-    croak( "listIdentifiers(): metadataPrefix is a required parameter" ) 
-	if ( ! exists( $opts{ metadataPrefix } )
-	    and ! exists( $opts{ resumptionToken } ) );
+    croak( "listIdentifiers(): the 'metadataPrefix' parameter is required" )
+	unless ( exists $opts{ 'metadataPrefix' } 
+              or defined $opts{ 'resumptionToken' } );
     my $uri = $self->{ baseURL }->clone();
 
     $uri->query_form( verb => 'ListIdentifiers', 
@@ -556,8 +538,10 @@ sub listIdentifiers {
 
     $token->set_handler( undef );
     $list->{ token } = $token->token() ? $token : undef; 
+
     $error->set_handler( undef );
     $list->{ error } = $error;
+
     return( $list );
 }
 
@@ -606,7 +590,7 @@ sub listSets {
     my $error = Net::OAI::Error->new( Handler => $token );
     my $parser = _parser( $error );
     debug( "parsing ListSets response " . $list->file() );
-    eval{ $parser->parse_uri( $list->file() ) };
+    eval { $parser->parse_uri( $list->file() ) };
     if ( $@ ) { _xmlError( $error ); } 
 
     $token->set_handler( undef );
@@ -618,7 +602,7 @@ sub listSets {
 
 =head2 baseURL()
 
-Gets or sets the base URL for the repository being harvested (as M<URI>).
+Gets or sets the base URL for the repository being harvested (as L<URI/>).
 
     $harvester->baseURL( 'http://memory.loc.gov/cgi-bin/oai2_0' );
 
@@ -664,21 +648,18 @@ sub _get {
     my $ua = $self->{ userAgent };
 
     my ($fh, $file);
-
     if ( $self->{ dumpDir } ) {
         my $filePrefix = $self->{lastDump}++;
         $file = sprintf("%s/%08d.xml", $self->{dumpDir}, $filePrefix);
         $fh = IO::File->new($file, 'w');
-    }
-
-    else {
+    } else {
         ( $fh, $file ) = tempfile(UNLINK => 1);
     }
 
     debug( "fetching ".$uri->as_string() );
     debug( "writing to file: $file" );
     my $request = HTTP::Request->new( GET => $uri->as_string() );
-    my $response = $ua->request( $request, sub { print $fh shift; }, 4096 );
+    my $response = $ua->request( $request, sub { print $fh shift; }, 8192 );
     close( $fh );
 
     if ( $response->is_error() ) { 
@@ -755,17 +736,17 @@ sub _xmlError {
 }
 
 
-sub _verifyMetadataHandler {
+sub _verifyHandler {
     my $package_or_instance = shift;
     if ( ref($package_or_instance) ) {
         $package_or_instance->isa('XML::SAX::Base')
-            or _fatal( "metadataHandler $package_or_instance must inherit from XML::SAX::Base\n" )
+            or _fatal( "Handler $package_or_instance must inherit from XML::SAX::Base\n" )
       }
     else {
         eval( "use $package_or_instance" );
-        _fatal( "unable to locate metadataHandler $package_or_instance in: " . 
+        _fatal( "unable to locate Handler $package_or_instance in: " . 
 	    join( "\n\t", @INC ) ) if $@; 
-        _fatal( "metadataHandler $package_or_instance must inherit from XML::SAX::Base\n" )
+        _fatal( "Handler $package_or_instance must inherit from XML::SAX::Base\n" )
             if ( ! grep { 'XML::SAX::Base' } eval( '@' . $package_or_instance . '::ISA' ) );
       }
     return( 1 );
@@ -903,7 +884,11 @@ L<Net::OAI::Record::Header>
 
 =item *
 
-L<Net::OAI::Record::Metadata>
+L<Net::OAI::Record::OAI_DC>
+
+=item *
+
+L<Net::OAI::Record::NamespaceFilter>
 
 =item *
 
@@ -915,24 +900,15 @@ L<Storable>
 
 =back
 
+
 =head1 AUTHORS
 
-=over 4
-
-=item * 
-
 Ed Summers <ehs@pobox.com>
 
-=item *
-
 Martin Emmerich <Martin.Emmerich@oew.de>
 
-=item *
-
 Thomas Berger <ThB@gymel.com>
 
-=back
-
 =cut
 
 1;
