@@ -1,8 +1,7 @@
 package Net::OAI::Identify;
 
 use strict;
-use base qw( XML::SAX::Base );
-use base qw( Net::OAI::Base );
+use base qw( XML::SAX::Base Net::OAI::Base );
 
 =head1 NAME
 
@@ -35,7 +34,7 @@ sub new {
     return( $self );
 }
 
-=head1 repositoryName() 
+=head2 repositoryName() 
 
 Returns the name of the repostiory.
 
@@ -46,7 +45,7 @@ sub repositoryName {
     return( $self->{ repositoryName } );
 }
 
-=head1 baseURL()
+=head2 baseURL()
 
 Returns the base URL used by the repository.
 
@@ -57,7 +56,7 @@ sub baseURL {
     return( $self->{ baseURL } );
 }
 
-=head1 protocolVersion()
+=head2 protocolVersion()
 
 Returns the version of the OAI-PMH used by the repository.
 
@@ -68,7 +67,7 @@ sub protocolVersion {
     return( $self->{ protocolVersion } );
 }
 
-=head1 earliestDatestamp()
+=head2 earliestDatestamp()
 
 Returns the earlies datestamp for records available in the repository.
 
@@ -79,7 +78,7 @@ sub earliestDatestamp {
     return( $self->{ earliestDatestamp } );
 }
 
-=head1 deletedRecord()
+=head2 deletedRecord()
 
 Indicates the way the repository works with deleted records. Should
 return I<no>, I<transient> or I<persistent>.
@@ -91,7 +90,7 @@ sub deletedRecord {
     return( $self->{ deletedRecord } );
 }
 
-=head1 granularity()
+=head2 granularity()
 
 Returns the granularity used by the repository.
 
@@ -102,7 +101,7 @@ sub granularity {
     return( $self->{ granularity } );
 }
 
-=head1 adminEmail()
+=head2 adminEmail()
 
 Returns the administrative email address for the repository. Since the 
 adminEmail elelemnt is allowed to repeat you will get all the emails (if more 
@@ -119,7 +118,7 @@ sub adminEmail {
     return( $self->{ adminEmails }[ 0 ] );
 }
 
-=head1 compression()
+=head2 compression()
 
 Returns the types of compression that the archive supports. Since the 
 compression element may repeat you may get all the values by using 
@@ -136,6 +135,12 @@ sub compression {
     return( $self->{ compressions }[ 0 ] );
 }
 
+=head1 TODO
+
+Support for the various C<description> containers.
+
+=cut
+
 ## SAX Handlers
 
 sub start_element {
