@@ -2,13 +2,12 @@ package Net::OAI::ListRecords;
 
 use strict;
 use base qw( XML::SAX::Base Net::OAI::Base );
-use Carp qw ( croak );
+use Carp qw( croak );
 use Net::OAI::Record;
 use Net::OAI::Record::Header;
 use File::Temp qw( tempfile );
 use Storable qw( store_fd fd_retrieve );
 use IO::File;
-use Carp qw( croak );
 
 =head1 NAME
 
@@ -20,6 +19,10 @@ Net::OAI::ListRecords - Results of the ListRecords OAI-PMH verb.
 
 =head1 METHODS
 
+Like all responses to OAI verbs, ListRecords is based on L<Net::OAI::Base>
+and inherits its methods.
+
+
 =head2 new()
 
 You probably don't want to be using this method yourself, since 
@@ -40,7 +43,7 @@ sub new {
         delete $opts{ recordHandler };
 	$package = $opts{ metadataHandler } = 'Net::OAI::Record::OAI_DC';
     }
-    Net::OAI::Harvester::_verifyMetadataHandler( $package );
+    Net::OAI::Harvester::_verifyHandler( $package );
 
     my $self = bless \%opts, ref( $class ) || $class;
     my ( $fh, $tempfile ) = tempfile(UNLINK => 1);
@@ -52,12 +55,15 @@ sub new {
     $Storable::Deparse = 1;
     $Storable::Eval = 1;
 
+    $self->{ _prefixmap } = {};
     return( $self );
 }
 
 =head2 next()
 
-Return the next metadata or record object or undef if there are no more.
+Returns the L<Net::OAI::Record> object for the next OAI record in the
+response, C<undef> if none remain. resumptionToken handling is performed
+automagically if the original request was listAllIdentifiers().
 
 =cut
 
@@ -105,6 +111,20 @@ sub recordHandler {
 
 ## SAX Handlers
 
+sub start_prefix_mapping {
+  my ($self, $mapping) = @_;
+  if ( $self->get_handler() ) {
+      return $self->SUPER::start_prefix_mapping( $mapping )};
+  $self->{ _prefixmap }->{$mapping->{ Prefix }} = $mapping;
+}
+
+sub end_prefix_mapping {
+  my ($self, $mapping) = @_;
+  if ( $self->get_handler() ) {
+      return $self->SUPER::end_prefix_mapping( $mapping )};
+  delete $self->{ _prefixmap }->{$mapping->{ Prefix }};
+}
+
 sub start_element {
     my ( $self, $element ) = @_;
     return $self->SUPER::start_element( $element ) unless $element->{NamespaceURI} eq Net::OAI::Harvester::XMLNS_OAI;
@@ -124,6 +144,8 @@ sub start_element {
 			Handler => (ref($self->{ metadataHandler }) ? $self->{ metadataHandler } : $self->{ metadataHandler }->new()),
 		     );
 	$self->set_handler( $header );
+        foreach my $mapping ( values %{$self->{_prefixmap}} ) {
+            $self->SUPER::start_prefix_mapping($mapping)};
     }
     elsif ( $element->{ LocalName } eq 'ListRecords' ) {
     }
@@ -151,7 +173,7 @@ sub end_element {
 	$self->set_handler( $self->{ OLD_Handler } );
         my $record;
         if ( $self->{ recordHandler } ) {
-	    $record = Net::OAI::Record->new(header => $header, alldata => $data)
+	    $record = Net::OAI::Record->new(header => $header, recorddata => $data)
         } else {
 	    $record = Net::OAI::Record->new(header => $header, metadata => $data)
 	};
