@@ -23,7 +23,7 @@ sub new {
     return bless {
 	header	    => $opts{ header },
 	@{[$opts{ metadata } ? (metadata => $opts{ metadata }) : ()]},
-	@{[$opts{ alldata } ? (alldata => $opts{ alldata }) : ()]},
+	@{[$opts{ recorddata } ? (recorddata => $opts{ recorddata }) : ()]},
     }, ref( $class ) || $class;
 }
 
@@ -46,14 +46,14 @@ sub metadata {
     return $self->{ metadata } || undef;
 }
 
-=head2 alldata()
+=head2 recorddata()
 
 =cut 
 
-sub alldata {
+sub recorddata {
     my $self = shift;
-#   return undef unless exists $self->{ alldata };
-    return $self->{ alldata } || undef;
+#   return undef unless exists $self->{ recorddata };
+    return $self->{ recorddata } || undef;
 }
 
 =head1 TODO
@@ -62,11 +62,7 @@ sub alldata {
 
 =head1 AUTHORS
 
-=over 4 
-
-=item * Ed Summers <ehs@pobox.com>
-
-=back
+Ed Summers <ehs@pobox.com>
 
 =cut
 
