@@ -3,7 +3,7 @@ package Net::OAI::Record::Header;
 use strict;
 use base qw( XML::SAX::Base );
 use Carp qw( carp );
-our $VERSION = 'v1.01.0';
+our $VERSION = 'v1.016.010';
 
 
 =head1 NAME
@@ -14,7 +14,7 @@ Net::OAI::Record::Header - class for record header representation
 
 =head1 DESCRIPTION
 
-Actually this class implements the filtering SAX parser for the 
+Actually this class implements a SAX filter for the 
 complete C<record> OAI-PMH element. The contents of the C<header> 
 child are collected into a header object and can be accessed by the
 methods documented here.
@@ -53,6 +53,8 @@ sub new {
 
 =head2 status()
 
+Gets the optional C<status> attribute of the OAI header and returns either "deleted" or "".
+
 =cut 
 
 sub status {
@@ -82,6 +84,7 @@ sub datestamp {
 }
 
 =head2 setSpecs()
+
 =head2 sets()  DEPRECATED
 
 =cut
@@ -98,6 +101,13 @@ sub sets {
 
 ## SAX Handlers
 
+sub start_prefix_mapping {
+  my ($self, $mapping) = @_;
+  if ( $self->get_handler() ) {
+      return $self->SUPER::start_prefix_mapping( $mapping )};
+  die "HEADER: would have to buffer @{[$mapping]}";
+}
+
 sub start_element {
     my ( $self, $element ) = @_;
     unless ( $element->{ NamespaceURI } eq Net::OAI::Harvester::XMLNS_OAI ) {
@@ -124,7 +134,7 @@ sub start_element {
 	$self->{ _insideAbout } = 1;
     }
     else {
-warn "who am I? ($tagName)";
+        carp "who am I? ($tagName)";
         return $self->SUPER::start_element($element);
     };
     return $self->SUPER::start_element($element) if $self->{ fwdAll };
@@ -152,7 +162,6 @@ sub end_element {
 	$self->{ _insideMetadata } = 0;
     }
     elsif ( $tagName eq 'about' ) {
-#	push( @{ $self->{ sets } }, $self->{ setSpec } );
 	$self->{ _insideAbout } = 0;
     }
     elsif ( $tagName eq 'record' ) {
@@ -162,7 +171,7 @@ sub end_element {
 	delete $self->{ _tagStack };
     }
     else {
-warn "who am I? ($tagName)";
+        carp "who am I? ($tagName)";
         return $self->SUPER::end_element( $element );
     };
     return $self->SUPER::end_element($element) if $self->{ fwdAll };
