@@ -1,7 +1,8 @@
 package Net::OAI::ResumptionToken;
 
 use strict;
-use base qw ( XML::SAX::Base );
+use base qw( XML::SAX::Base );
+use Carp qw( carp );
 
 
 =head1 NAME
@@ -72,21 +73,10 @@ sub cursor {
     return( $self->{ cursor } );
 }
 
-=head1 TODO
-
-=head1 SEE ALSO
-
-=over 4
-
-=back
 
 =head1 AUTHORS
 
-=over 4 
-
-=item * Ed Summers <ehs@pobox.com>
-
-=back
+Ed Summers <ehs@pobox.com>
 
 =cut
 
@@ -94,6 +84,13 @@ sub cursor {
 
 ## all children of Net::OAI::Base should call this to make sure
 ## certain object properties are set
+sub start_prefix_mapping {
+  my ($self, $mapping) = @_;
+  die "rT: self not defined" unless defined $self;
+  return $self->SUPER::start_prefix_mapping( $mapping ) if $self->get_handler();
+  die "rT: start_prefix_mapping @{[$mapping]} w/o Handler";
+}
+
 
 sub start_element { 
     my ( $self, $element ) = @_;
@@ -106,7 +103,8 @@ sub start_element {
 	$self->{ cursor } = $attr->{ '{}cursor' }{ Value } if $attr->{ '{}cursor' };
 	$self->{ resumptionTokenText } = "";
 	$self->{ _insideResumptionToken } = 1;
-    } elsif ( $self->{ _insideResumptionToken } ) {       # should be error?
+    } elsif ( $self->{ _insideResumptionToken } ) {
+        carp "start of unhandled subelement ".$element->{ Name }." within resumptionToken";
     } else { 
 	$self->SUPER::start_element( $element );
     }
@@ -119,7 +117,8 @@ sub end_element {
     if ( $element->{ LocalName } eq 'resumptionToken' ) {
         Net::OAI::Harvester::debug( "caught resumption token" );
 	$self->{ _insideResumptionToken } = 0;
-    } elsif ( $self->{ _insideResumptionToken } ) {       # should be error?
+    } elsif ( $self->{ _insideResumptionToken } ) {
+        carp "end of unhandled subelement ".$element->{ Name }." within resumptionToken";
     } else { 
 	$self->SUPER::end_element( $element );
     }
